using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.XR.Interaction.Toolkit;
using Unity.XR.CoreUtils;

public class CharacterHelper : MonoBehaviour
{

    private XROrigin XROrigin;
    private CharacterController CharacterController;
    private CharacterControllerDriver driver;

    public FootSteps footSteps;
    public Vector3 currentPos;
    public Vector3 lastPos;


    void Start()
    {
        XROrigin = GetComponent<XROrigin>();
        CharacterController = GetComponent<CharacterController>();
        driver = GetComponent<CharacterControllerDriver>();
    }

    void Update()
    {   
        currentPos = CharacterController.transform.position;
        if(currentPos != lastPos) {
            doFootStepSound();
        }
        lastPos = currentPos;
        UpdateCharacterController();
    }

    protected virtual void UpdateCharacterController()
        {
            if (XROrigin == null || CharacterController == null)
                return;

            var height = Mathf.Clamp(XROrigin.CameraInOriginSpaceHeight, driver.minHeight, driver.maxHeight);

            Vector3 center = XROrigin.CameraInOriginSpacePos;
            center.y = height / 2f + CharacterController.skinWidth;

            CharacterController.height = height;
            CharacterController.center = center;
        }

    private void doFootStepSound()
        {
            footSteps.Step();
        }

}
