using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.AI;
using UnityEngine.Animations.Rigging;
using UnityEngine.XR.Interaction.Toolkit;

public class GatekeeperBehaviour : MonoBehaviour
{
    public Transform playerTransform;
    NavMeshAgent agent;
    public Animator animator;
    public Animator handAnim;
    public TwoBoneIKConstraint constraint;
    public float triggerDistance;
    public XRSocketInteractor socket;
    public XRGrabInteractable map;
    public Highlighter mapHighlighter;
    public Highlighter papersHighlighter;
    public XRInteractionManager xRInteractionManager;

    public FollowTargets headTarget;

    public GateController gate;

    private AudioSource audioSource;

    public AudioClip clip1;
    public AudioClip clip2;
    public AudioClip clip3;



    private bool dialogueStarted;
    private bool hasBeenRun;

    // Start is called before the first frame update
    void Start()
    {
        dialogueStarted = false;
        audioSource = GetComponent<AudioSource>();
        hasBeenRun = false;
        agent = GetComponent<NavMeshAgent>();
    }

    public void WalkToPlayer()
    {
        StartCoroutine(updatePosition());
    }


    IEnumerator updatePosition()
    {
        while(true)
        {
            agent.destination = playerTransform.position;
            if (agent.hasPath && agent.remainingDistance <= agent.stoppingDistance)
            {
                if(agent.velocity.sqrMagnitude == 0f)
                {
                    if(!dialogueStarted)
                    {
                        dialogueStarted = true;
                        audioSource.PlayOneShot(clip1);
                        papersHighlighter.HighlightObject();
                    }  
                    agent.updateRotation = true;
                    if(!hasBeenRun)
                        RaiseHand();
                } 
            }

            yield return new WaitForSeconds(0.5f);
            
        }
    }

    void RaiseHand()
    {
        StopCoroutine(updatePosition());
        constraint.weight = 1;
        handAnim.SetBool("IsClose", true);
    }

    public void PlacePapers()
    {
        if (!hasBeenRun)
        {
            audioSource.PlayOneShot(clip2);
            handAnim.SetBool("IsClose", false);
            handAnim.SetBool("PapersPlaced", true);
            StartCoroutine(ReadPaper());
        }
    }

    IEnumerator ReadPaper()
    {
        headTarget.NextTarget();
        yield return new WaitForSeconds(2.5f);
        papersHighlighter.HighlightObject();
        headTarget.NextTarget();
        yield break;
    }

    public void GetMap()
    {
        if(!hasBeenRun)
        {
            audioSource.PlayOneShot(clip3);
            hasBeenRun = true;
            handAnim.SetBool("PapersPlaced", false);
            handAnim.SetBool("PapersPicked", true);
            StartCoroutine(PickUpMap());
        } else
        {
            constraint.weight = 0;
            EndOfInteraction();
        }
    }

    public void AreaLeft()
    {
        StopAllCoroutines();
        constraint.weight = 0;
        handAnim.SetBool("IsClose", false);
    }

    IEnumerator PickUpMap()
    {
        yield return new WaitForSeconds(2.5f);
        Debug.Log("Giving map");
        xRInteractionManager.SelectEnter((IXRSelectInteractor) socket, map);
        mapHighlighter.HighlightObject();
        yield break;
    }

    private void EndOfInteraction()
    {
        gate.Open();
    }


    // Update is called once per frame
    void Update()
    {
        animator.SetFloat("Speed", agent.velocity.magnitude);
    }
}
